#!/usr/bin/env python
# -*- coding: utf-8 -*-
 
"""Ce module est un test"""

__version__ = "0.0.2"

from menu.get_view import show
from menu.menu.menu_widget import FrameMenu
from menu.menu.view import gui_window